
#ifndef EL__MIME_BACKEND_MAILCAP_H
#define EL__MIME_BACKEND_MAILCAP_H

#include "main/module.h"
#include "mime/backend/common.h"

extern struct mime_backend mailcap_mime_backend;
extern struct module mailcap_mime_module;

#endif
